@@ -29,7 +29,22 @@ fzero.nolag <- function(PKindex,
       if ( is.null(Tabs) || is.null(Vm) || is.null(Km) || is.null(Vd) ) {
         par<-data.frame(Parameter=c("Tabs","Vm","Km","Vd"),Initial=c(0))
         par<-edit(par)
-        par<-check(par)
+        repeat{
+           if ( par[1,2] == 0 || par[2,2] ==0 || par[3,2]==0 || par[4,2]==0){
+             cat("\n")
+             cat("**********************************\n")
+             cat(" Parameter value can not be zero. \n")
+             cat(" Press enter to continue.         \n")
+             cat("**********************************\n\n")
+             readline()
+             cat("\n")
+             par<-edit(par)}   
+           else{
+             break
+             return(edit(par))}
+        } 
+        cat("\n")       
+        show(par)
         
       }
    } 
@@ -38,7 +53,22 @@ fzero.nolag <- function(PKindex,
       if ( is.null(Tabs) || is.null(kel) || is.null(Vd)) {
         par<-data.frame(Parameter=c("Tabs","kel","Vd"),Initial=c(0))
         par<-edit(par)
-        par<-check(par)
+        repeat{
+           if ( par[1,2] == 0 || par[2,2] ==0 || par[3,2]==0){
+             cat("\n")
+             cat("**********************************\n")
+             cat(" Parameter value can not be zero. \n")
+             cat(" Press enter to continue.         \n")
+             cat("**********************************\n\n")
+             readline()
+             cat("\n")
+             par<-edit(par)}   
+           else{
+             break
+             return(edit(par))}
+        } 
+        cat("\n")       
+        show(par)
 
       }
    }
@@ -55,7 +85,7 @@ fzero.nolag <- function(PKindex,
       list(dCpdt) 
       } 
    
-      modfun <- function(time,Tabs,kel,Vd) { 
+      modfun1 <- function(time,Tabs,kel,Vd) { 
          out <- lsoda(0,c(0,time),defun,parms=c(Tabs=Tabs,kel=kel,Vd=Vd),
                       rtol=1e-8,atol=1e-8) 
          out[-1,2]
@@ -71,7 +101,7 @@ fzero.nolag <- function(PKindex,
       list(dCpdt) 
       }   
    
-      modfun <- function(time,Tabs,Vm,Km,Vd) { 
+      modfun2 <- function(time,Tabs,Vm,Km,Vd) { 
       out <- lsoda(0,c(0,time),defun,parms=c(Tabs=Tabs,Vm=Vm,Km=Km,Vd=Vd),
                    rtol=1e-6,atol=1e-8) 
       out[-1,2]
@@ -90,11 +120,11 @@ fzero.nolag <- function(PKindex,
      cat("\n\n               << Subject",i,">>\n\n" )  
      objfun <- function(par) {
         if (MMe) {
-           out<-modfun(PKindex$time[PKindex$Subject==i],par[1],par[2],par[3],par[4])
+           out<-modfun2(PKindex$time[PKindex$Subject==i],par[1],par[2],par[3],par[4])
         } 
         else {
            ## No MM elimination
-           out<-modfun(PKindex$time[PKindex$Subject==i],par[1],par[2],par[3])
+           out<-modfun1(PKindex$time[PKindex$Subject==i],par[1],par[2],par[3])
         }
       gift <- which( PKindex$conc[PKindex$Subject==i] != 0 )
       switch(pick,
@@ -149,7 +179,7 @@ fzero.nolag <- function(PKindex,
      cat("\n<< Residual sum-of-squares and parameter values fitted by nls >>\n\n")
 
      if (MMe) {
-        fm<-nls(conc~modfun(time,Tabs,Vm,Km,Vd),data=PKindex, algorithm="default",subset=Subject==i,
+        fm<-nls(conc~modfun2(time,Tabs,Vm,Km,Vd),data=PKindex, algorithm="default",subset=Subject==i,
             start=list(Tabs=opt$par[1],Vm=opt$par[2],Km=opt$par[3],Vd=opt$par[4]),trace=TRUE,
             nls.control(maxiter=50,tol=10,minFactor=1/1024))
         cat("\n")
@@ -157,7 +187,7 @@ fzero.nolag <- function(PKindex,
      } 
      else {
         ## No MM elimination
-        fm<-nls(conc~modfun(time,Tabs,kel,Vd),data=PKindex, algorithm="default",subset=Subject==i,
+        fm<-nls(conc~modfun1(time,Tabs,kel,Vd),data=PKindex, algorithm="default",subset=Subject==i,
             start=list(Tabs=opt$par[1],kel=opt$par[2],Vd=opt$par[3]),trace=TRUE,
             nls.control(tol=1))
         cat("\n")
@@ -213,7 +243,24 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
     if ( is.null(Tabs) || is.null(kel) || is.null(Vd)) {
        par<-data.frame(Parameter=c("Tabs","kel","Vd"),Initial=c(0))
        par<-edit(par)
-       par<-check(par)
+       repeat{
+           if ( par[1,2] == 0 || par[2,2] ==0 || par[3,2]==0){
+             cat("\n")
+             cat("**********************************\n")
+             cat(" Parameter value can not be zero. \n")
+             cat(" Press enter to continue.         \n")
+             cat("**********************************\n\n")
+             readline()
+             cat("\n")
+             par<-edit(par)}   
+           else{
+             break
+             return(edit(par))}
+        } 
+        cat("\n")       
+        show(par)
+       
+       
        cat("\n")
        par1<-par[1,2]
        par2<-par[2,2]
@@ -229,7 +276,24 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
     if ( is.null(Tabs) || is.null(Vm) || is.null(Km) || is.null(Vd)){
        par<-data.frame(Parameter=c("Tabs","Vm","Km","Vd"),Initial=c(0))
        par<-edit(par)
-       par<-check(par)
+       repeat{
+           if ( par[1,2] == 0 || par[2,2] ==0 || par[3,2]==0 || par[4,2]==0){
+             cat("\n")
+             cat("**********************************\n")
+             cat(" Parameter value can not be zero. \n")
+             cat(" Press enter to continue.         \n")
+             cat("**********************************\n\n")
+             readline()
+             cat("\n")
+             par<-edit(par)}   
+           else{
+             break
+             return(edit(par))}
+        } 
+        cat("\n")       
+        show(par)
+       
+       
        cat("\n")
        par1<-par[1,2]
        par2<-par[2,2]
@@ -311,10 +375,55 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
          if (! MMe){
            cat("\n\nEnter error factor for Tabs\n")
            factor1<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor1 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor1<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor1)}
+           } 
+           
            cat("\n\nEnter error factor for kel\n")
            factor2<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor2 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor2<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor2)}
+           } 
+           
            cat("\nEnter error factor for Vd\n")
            factor3<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor3 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor3<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor3)}
+           } 
+           
            PKindex<-vector(Subject,mode="list")
            for( i in 1:Subject)  {
              cat("\n\n             << Subject",i,">>\n\n" )  
@@ -366,12 +475,72 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
          else{
            cat("\n\nEnter error factor for Tabs\n")
            factor1<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor1 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor1<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor1)}
+           } 
+           
            cat("\n\nEnter error factor for Vm\n")
            factor2<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor2 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor2<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor2)}
+           } 
+           
            cat("\nEnter error factor for Km\n")
            factor3<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor3 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor3<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor3)}
+           } 
+           
            cat("\nEnter error factor for Vd\n")
            factor4<-scan(nlines=1,quiet=TRUE)
+           repeat{
+              if ( factor4 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor4<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor4)}
+           } 
+           
            PKindex<-vector(Subject,mode="list")
            for( i in 1:Subject)  {
              cat("\n\n             << Subject",i,">>\n\n" )  
@@ -457,10 +626,55 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
        if (! MMe){
          cat("\nEnter error factor for Tabs\n")
          factor1<-scan(nlines=1,quiet=TRUE)
+         repeat{
+              if ( factor1 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor1<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor1)}
+           } 
+         
          cat("\nEnter error factor for kel\n")
          factor2<-scan(nlines=1,quiet=TRUE)
+         repeat{
+              if ( factor2 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor2<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor2)}
+           } 
+         
          cat("\nEnter error factor for Vd\n")
          factor3<-scan(nlines=1,quiet=TRUE)
+         repeat{
+              if ( factor3 == 0 ){
+                cat("\n")
+                cat("**********************************\n")
+                cat(" Parameter value can not be zero. \n")
+                cat(" Press enter to continue.         \n")
+                cat("**********************************\n\n")
+                readline()
+                cat("\n")
+                factor3<-scan(nlines=1,quiet=TRUE)}   
+           else{
+                break
+                return(factor3)}
+           } 
+         
          cat("\n")
          cat("********************************************************\n")
          cat("Summary Table                                           \n")
@@ -546,10 +760,10 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
                     while(Vd<=0){
                       Vd<-par3*runif(1,min=-factor3,max=factor3)+par3}}     
               )    
-              time<-PKtime$time
+              time1<-PKtime$time
               parms<-c(Tabs=Tabs,kel=kel,Vd=Vd) 
-              XX<-data.frame(lsoda(0, c(0,time), defun, parms))   
-              C1.lsoda[[j]]<-data.frame(XX[2:(length(time)+1),1],XX[2:(length(time)+1),2])
+              XX<-data.frame(lsoda(0, c(0,time1), defun, parms))   
+              C1.lsoda[[j]]<-data.frame(XX[2:(length(time1)+1),1],XX[2:(length(time1)+1),2])
               colnames(C1.lsoda[[j]])<-list("time","concentration")
            }
            else{
@@ -606,10 +820,10 @@ szero.nolag<- function(Subject=NULL,  # N Subj's
                     while(Vd<=0){
                        Vd<-par4*runif(1,min=-factor4,max=factor4)+par4}}         
               )
-              time<-PKtime$time
+              time1<-PKtime$time
               parms<-c(Tabs=Tabs,Vm=Vm,Km=Km,Vd=Vd) 
-              XX<-data.frame(lsoda(0,c(0,time), defun, parms)) 
-              C1.lsoda[[j]]<-data.frame(XX[2:(length(time)+1),1],XX[2:(length(time)+1),2])
+              XX<-data.frame(lsoda(0,c(0,time1), defun, parms)) 
+              C1.lsoda[[j]]<-data.frame(XX[2:(length(time1)+1),1],XX[2:(length(time1)+1),2])
               colnames(C1.lsoda[[j]])<-list("time","concentration")     
            } 
          }        
